pub async fn fetch_small_asset(
provider: &dyn ReleaseProvider,
asset: &ReleaseAsset,
) -> Result<Vec<u8>>Expand description
Fully buffer an asset into memory. Returns the bytes. Used for signatures and checksum files, which are small.
pub async fn fetch_small_asset(
provider: &dyn ReleaseProvider,
asset: &ReleaseAsset,
) -> Result<Vec<u8>>Fully buffer an asset into memory. Returns the bytes. Used for signatures and checksum files, which are small.